@@ -444,7 +444,7 @@ class AssetBin(gameduino2.base.GD2):
 
         hh = open(name, "w")
         if self.asset_file is None:
-            print >>hh, "static const PROGMEM prog_uchar %s__assets[%d] = {" % (self.prefix, len(commandblock))
+            print >>hh, "static const PROGMEM uint8_t %s__assets[%d] = {" % (self.prefix, len(commandblock))
             print >>hh, textwrap.fill(", ".join(["%d" % ord(c) for c in commandblock]))
             print >>hh, "};"
             print >>hh, "#define %sLOAD_ASSETS()  GD.copy(%s__assets, sizeof(%s__assets))" % (self.prefix, self.prefix, self.prefix)
